"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComposerEnvironmentXConfigXDatabaseConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MACHINE_TYPE_FIELD_NUMBER: builtins.int
    machine_type: builtins.str
    def __init__(
        self,
        *,
        machine_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["machine_type", b"machine_type"]) -> None: ...

global___ComposerEnvironmentXConfigXDatabaseConfig = ComposerEnvironmentXConfigXDatabaseConfig

@typing_extensions.final
class ComposerEnvironmentXConfigXEncryptionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KMS_KEY_NAME_FIELD_NUMBER: builtins.int
    kms_key_name: builtins.str
    def __init__(
        self,
        *,
        kms_key_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kms_key_name", b"kms_key_name"]) -> None: ...

global___ComposerEnvironmentXConfigXEncryptionConfig = ComposerEnvironmentXConfigXEncryptionConfig

@typing_extensions.final
class ComposerEnvironmentXConfigXMaintenanceWindow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    END_TIME_FIELD_NUMBER: builtins.int
    RECURRENCE_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    end_time: builtins.str
    recurrence: builtins.str
    start_time: builtins.str
    def __init__(
        self,
        *,
        end_time: builtins.str = ...,
        recurrence: builtins.str = ...,
        start_time: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["end_time", b"end_time", "recurrence", b"recurrence", "start_time", b"start_time"]) -> None: ...

global___ComposerEnvironmentXConfigXMaintenanceWindow = ComposerEnvironmentXConfigXMaintenanceWindow

@typing_extensions.final
class ComposerEnvironmentXConfigXMasterAuthorizedNetworksConfigXCidrBlocks(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CIDR_BLOCK_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    cidr_block: builtins.str
    display_name: builtins.str
    def __init__(
        self,
        *,
        cidr_block: builtins.str = ...,
        display_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cidr_block", b"cidr_block", "display_name", b"display_name"]) -> None: ...

global___ComposerEnvironmentXConfigXMasterAuthorizedNetworksConfigXCidrBlocks = ComposerEnvironmentXConfigXMasterAuthorizedNetworksConfigXCidrBlocks

@typing_extensions.final
class ComposerEnvironmentXConfigXMasterAuthorizedNetworksConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLED_FIELD_NUMBER: builtins.int
    CIDR_BLOCKS_FIELD_NUMBER: builtins.int
    enabled: builtins.bool
    @property
    def cidr_blocks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComposerEnvironmentXConfigXMasterAuthorizedNetworksConfigXCidrBlocks]: ...
    def __init__(
        self,
        *,
        enabled: builtins.bool = ...,
        cidr_blocks: collections.abc.Iterable[global___ComposerEnvironmentXConfigXMasterAuthorizedNetworksConfigXCidrBlocks] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cidr_blocks", b"cidr_blocks", "enabled", b"enabled"]) -> None: ...

global___ComposerEnvironmentXConfigXMasterAuthorizedNetworksConfig = ComposerEnvironmentXConfigXMasterAuthorizedNetworksConfig

@typing_extensions.final
class ComposerEnvironmentXConfigXNodeConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class IpAllocationPolicyEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DISK_SIZE_GB_FIELD_NUMBER: builtins.int
    ENABLE_IP_MASQ_AGENT_FIELD_NUMBER: builtins.int
    IP_ALLOCATION_POLICY_FIELD_NUMBER: builtins.int
    MACHINE_TYPE_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    OAUTH_SCOPES_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_FIELD_NUMBER: builtins.int
    SUBNETWORK_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    disk_size_gb: builtins.float
    enable_ip_masq_agent: builtins.bool
    @property
    def ip_allocation_policy(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    machine_type: builtins.str
    network: builtins.str
    @property
    def oauth_scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    service_account: builtins.str
    subnetwork: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    zone: builtins.str
    def __init__(
        self,
        *,
        disk_size_gb: builtins.float = ...,
        enable_ip_masq_agent: builtins.bool = ...,
        ip_allocation_policy: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        machine_type: builtins.str = ...,
        network: builtins.str = ...,
        oauth_scopes: collections.abc.Iterable[builtins.str] | None = ...,
        service_account: builtins.str = ...,
        subnetwork: builtins.str = ...,
        tags: collections.abc.Iterable[builtins.str] | None = ...,
        zone: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disk_size_gb", b"disk_size_gb", "enable_ip_masq_agent", b"enable_ip_masq_agent", "ip_allocation_policy", b"ip_allocation_policy", "machine_type", b"machine_type", "network", b"network", "oauth_scopes", b"oauth_scopes", "service_account", b"service_account", "subnetwork", b"subnetwork", "tags", b"tags", "zone", b"zone"]) -> None: ...

global___ComposerEnvironmentXConfigXNodeConfig = ComposerEnvironmentXConfigXNodeConfig

@typing_extensions.final
class ComposerEnvironmentXConfigXPrivateEnvironmentConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOUD_COMPOSER_CONNECTION_SUBNETWORK_FIELD_NUMBER: builtins.int
    CLOUD_COMPOSER_NETWORK_IPV4_CIDR_BLOCK_FIELD_NUMBER: builtins.int
    CLOUD_SQL_IPV4_CIDR_BLOCK_FIELD_NUMBER: builtins.int
    ENABLE_PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    ENABLE_PRIVATELY_USED_PUBLIC_IPS_FIELD_NUMBER: builtins.int
    MASTER_IPV4_CIDR_BLOCK_FIELD_NUMBER: builtins.int
    WEB_SERVER_IPV4_CIDR_BLOCK_FIELD_NUMBER: builtins.int
    cloud_composer_connection_subnetwork: builtins.str
    cloud_composer_network_ipv4_cidr_block: builtins.str
    cloud_sql_ipv4_cidr_block: builtins.str
    enable_private_endpoint: builtins.bool
    enable_privately_used_public_ips: builtins.bool
    master_ipv4_cidr_block: builtins.str
    web_server_ipv4_cidr_block: builtins.str
    def __init__(
        self,
        *,
        cloud_composer_connection_subnetwork: builtins.str = ...,
        cloud_composer_network_ipv4_cidr_block: builtins.str = ...,
        cloud_sql_ipv4_cidr_block: builtins.str = ...,
        enable_private_endpoint: builtins.bool = ...,
        enable_privately_used_public_ips: builtins.bool = ...,
        master_ipv4_cidr_block: builtins.str = ...,
        web_server_ipv4_cidr_block: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cloud_composer_connection_subnetwork", b"cloud_composer_connection_subnetwork", "cloud_composer_network_ipv4_cidr_block", b"cloud_composer_network_ipv4_cidr_block", "cloud_sql_ipv4_cidr_block", b"cloud_sql_ipv4_cidr_block", "enable_private_endpoint", b"enable_private_endpoint", "enable_privately_used_public_ips", b"enable_privately_used_public_ips", "master_ipv4_cidr_block", b"master_ipv4_cidr_block", "web_server_ipv4_cidr_block", b"web_server_ipv4_cidr_block"]) -> None: ...

global___ComposerEnvironmentXConfigXPrivateEnvironmentConfig = ComposerEnvironmentXConfigXPrivateEnvironmentConfig

@typing_extensions.final
class ComposerEnvironmentXConfigXSoftwareConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AirflowConfigOverridesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class EnvVariablesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class PypiPackagesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    AIRFLOW_CONFIG_OVERRIDES_FIELD_NUMBER: builtins.int
    ENV_VARIABLES_FIELD_NUMBER: builtins.int
    IMAGE_VERSION_FIELD_NUMBER: builtins.int
    PYPI_PACKAGES_FIELD_NUMBER: builtins.int
    PYTHON_VERSION_FIELD_NUMBER: builtins.int
    SCHEDULER_COUNT_FIELD_NUMBER: builtins.int
    @property
    def airflow_config_overrides(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def env_variables(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    image_version: builtins.str
    @property
    def pypi_packages(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    python_version: builtins.str
    scheduler_count: builtins.float
    def __init__(
        self,
        *,
        airflow_config_overrides: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        env_variables: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        image_version: builtins.str = ...,
        pypi_packages: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        python_version: builtins.str = ...,
        scheduler_count: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["airflow_config_overrides", b"airflow_config_overrides", "env_variables", b"env_variables", "image_version", b"image_version", "pypi_packages", b"pypi_packages", "python_version", b"python_version", "scheduler_count", b"scheduler_count"]) -> None: ...

global___ComposerEnvironmentXConfigXSoftwareConfig = ComposerEnvironmentXConfigXSoftwareConfig

@typing_extensions.final
class ComposerEnvironmentXConfigXWebServerConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MACHINE_TYPE_FIELD_NUMBER: builtins.int
    machine_type: builtins.str
    def __init__(
        self,
        *,
        machine_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["machine_type", b"machine_type"]) -> None: ...

global___ComposerEnvironmentXConfigXWebServerConfig = ComposerEnvironmentXConfigXWebServerConfig

@typing_extensions.final
class ComposerEnvironmentXConfigXWebServerNetworkAccessControlXAllowedIpRange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    description: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "value", b"value"]) -> None: ...

global___ComposerEnvironmentXConfigXWebServerNetworkAccessControlXAllowedIpRange = ComposerEnvironmentXConfigXWebServerNetworkAccessControlXAllowedIpRange

@typing_extensions.final
class ComposerEnvironmentXConfigXWebServerNetworkAccessControl(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_IP_RANGE_FIELD_NUMBER: builtins.int
    @property
    def allowed_ip_range(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComposerEnvironmentXConfigXWebServerNetworkAccessControlXAllowedIpRange]: ...
    def __init__(
        self,
        *,
        allowed_ip_range: collections.abc.Iterable[global___ComposerEnvironmentXConfigXWebServerNetworkAccessControlXAllowedIpRange] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_ip_range", b"allowed_ip_range"]) -> None: ...

global___ComposerEnvironmentXConfigXWebServerNetworkAccessControl = ComposerEnvironmentXConfigXWebServerNetworkAccessControl

@typing_extensions.final
class ComposerEnvironmentXConfigXWorkloadsConfigXScheduler(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COUNT_FIELD_NUMBER: builtins.int
    CPU_FIELD_NUMBER: builtins.int
    MEMORY_GB_FIELD_NUMBER: builtins.int
    STORAGE_GB_FIELD_NUMBER: builtins.int
    count: builtins.float
    cpu: builtins.float
    memory_gb: builtins.float
    storage_gb: builtins.float
    def __init__(
        self,
        *,
        count: builtins.float = ...,
        cpu: builtins.float = ...,
        memory_gb: builtins.float = ...,
        storage_gb: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["count", b"count", "cpu", b"cpu", "memory_gb", b"memory_gb", "storage_gb", b"storage_gb"]) -> None: ...

global___ComposerEnvironmentXConfigXWorkloadsConfigXScheduler = ComposerEnvironmentXConfigXWorkloadsConfigXScheduler

@typing_extensions.final
class ComposerEnvironmentXConfigXWorkloadsConfigXWebServer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CPU_FIELD_NUMBER: builtins.int
    MEMORY_GB_FIELD_NUMBER: builtins.int
    STORAGE_GB_FIELD_NUMBER: builtins.int
    cpu: builtins.float
    memory_gb: builtins.float
    storage_gb: builtins.float
    def __init__(
        self,
        *,
        cpu: builtins.float = ...,
        memory_gb: builtins.float = ...,
        storage_gb: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cpu", b"cpu", "memory_gb", b"memory_gb", "storage_gb", b"storage_gb"]) -> None: ...

global___ComposerEnvironmentXConfigXWorkloadsConfigXWebServer = ComposerEnvironmentXConfigXWorkloadsConfigXWebServer

@typing_extensions.final
class ComposerEnvironmentXConfigXWorkloadsConfigXWorker(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CPU_FIELD_NUMBER: builtins.int
    MAX_COUNT_FIELD_NUMBER: builtins.int
    MEMORY_GB_FIELD_NUMBER: builtins.int
    MIN_COUNT_FIELD_NUMBER: builtins.int
    STORAGE_GB_FIELD_NUMBER: builtins.int
    cpu: builtins.float
    max_count: builtins.float
    memory_gb: builtins.float
    min_count: builtins.float
    storage_gb: builtins.float
    def __init__(
        self,
        *,
        cpu: builtins.float = ...,
        max_count: builtins.float = ...,
        memory_gb: builtins.float = ...,
        min_count: builtins.float = ...,
        storage_gb: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cpu", b"cpu", "max_count", b"max_count", "memory_gb", b"memory_gb", "min_count", b"min_count", "storage_gb", b"storage_gb"]) -> None: ...

global___ComposerEnvironmentXConfigXWorkloadsConfigXWorker = ComposerEnvironmentXConfigXWorkloadsConfigXWorker

@typing_extensions.final
class ComposerEnvironmentXConfigXWorkloadsConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCHEDULER_FIELD_NUMBER: builtins.int
    WEB_SERVER_FIELD_NUMBER: builtins.int
    WORKER_FIELD_NUMBER: builtins.int
    @property
    def scheduler(self) -> global___ComposerEnvironmentXConfigXWorkloadsConfigXScheduler: ...
    @property
    def web_server(self) -> global___ComposerEnvironmentXConfigXWorkloadsConfigXWebServer: ...
    @property
    def worker(self) -> global___ComposerEnvironmentXConfigXWorkloadsConfigXWorker: ...
    def __init__(
        self,
        *,
        scheduler: global___ComposerEnvironmentXConfigXWorkloadsConfigXScheduler | None = ...,
        web_server: global___ComposerEnvironmentXConfigXWorkloadsConfigXWebServer | None = ...,
        worker: global___ComposerEnvironmentXConfigXWorkloadsConfigXWorker | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["scheduler", b"scheduler", "web_server", b"web_server", "worker", b"worker"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["scheduler", b"scheduler", "web_server", b"web_server", "worker", b"worker"]) -> None: ...

global___ComposerEnvironmentXConfigXWorkloadsConfig = ComposerEnvironmentXConfigXWorkloadsConfig

@typing_extensions.final
class ComposerEnvironmentXConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AIRFLOW_URI_FIELD_NUMBER: builtins.int
    DAG_GCS_PREFIX_FIELD_NUMBER: builtins.int
    ENVIRONMENT_SIZE_FIELD_NUMBER: builtins.int
    GKE_CLUSTER_FIELD_NUMBER: builtins.int
    NODE_COUNT_FIELD_NUMBER: builtins.int
    DATABASE_CONFIG_FIELD_NUMBER: builtins.int
    ENCRYPTION_CONFIG_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    MASTER_AUTHORIZED_NETWORKS_CONFIG_FIELD_NUMBER: builtins.int
    NODE_CONFIG_FIELD_NUMBER: builtins.int
    PRIVATE_ENVIRONMENT_CONFIG_FIELD_NUMBER: builtins.int
    SOFTWARE_CONFIG_FIELD_NUMBER: builtins.int
    WEB_SERVER_CONFIG_FIELD_NUMBER: builtins.int
    WEB_SERVER_NETWORK_ACCESS_CONTROL_FIELD_NUMBER: builtins.int
    WORKLOADS_CONFIG_FIELD_NUMBER: builtins.int
    airflow_uri: builtins.str
    dag_gcs_prefix: builtins.str
    environment_size: builtins.str
    gke_cluster: builtins.str
    node_count: builtins.float
    @property
    def database_config(self) -> global___ComposerEnvironmentXConfigXDatabaseConfig: ...
    @property
    def encryption_config(self) -> global___ComposerEnvironmentXConfigXEncryptionConfig: ...
    @property
    def maintenance_window(self) -> global___ComposerEnvironmentXConfigXMaintenanceWindow: ...
    @property
    def master_authorized_networks_config(self) -> global___ComposerEnvironmentXConfigXMasterAuthorizedNetworksConfig: ...
    @property
    def node_config(self) -> global___ComposerEnvironmentXConfigXNodeConfig: ...
    @property
    def private_environment_config(self) -> global___ComposerEnvironmentXConfigXPrivateEnvironmentConfig: ...
    @property
    def software_config(self) -> global___ComposerEnvironmentXConfigXSoftwareConfig: ...
    @property
    def web_server_config(self) -> global___ComposerEnvironmentXConfigXWebServerConfig: ...
    @property
    def web_server_network_access_control(self) -> global___ComposerEnvironmentXConfigXWebServerNetworkAccessControl: ...
    @property
    def workloads_config(self) -> global___ComposerEnvironmentXConfigXWorkloadsConfig: ...
    def __init__(
        self,
        *,
        airflow_uri: builtins.str = ...,
        dag_gcs_prefix: builtins.str = ...,
        environment_size: builtins.str = ...,
        gke_cluster: builtins.str = ...,
        node_count: builtins.float = ...,
        database_config: global___ComposerEnvironmentXConfigXDatabaseConfig | None = ...,
        encryption_config: global___ComposerEnvironmentXConfigXEncryptionConfig | None = ...,
        maintenance_window: global___ComposerEnvironmentXConfigXMaintenanceWindow | None = ...,
        master_authorized_networks_config: global___ComposerEnvironmentXConfigXMasterAuthorizedNetworksConfig | None = ...,
        node_config: global___ComposerEnvironmentXConfigXNodeConfig | None = ...,
        private_environment_config: global___ComposerEnvironmentXConfigXPrivateEnvironmentConfig | None = ...,
        software_config: global___ComposerEnvironmentXConfigXSoftwareConfig | None = ...,
        web_server_config: global___ComposerEnvironmentXConfigXWebServerConfig | None = ...,
        web_server_network_access_control: global___ComposerEnvironmentXConfigXWebServerNetworkAccessControl | None = ...,
        workloads_config: global___ComposerEnvironmentXConfigXWorkloadsConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["database_config", b"database_config", "encryption_config", b"encryption_config", "maintenance_window", b"maintenance_window", "master_authorized_networks_config", b"master_authorized_networks_config", "node_config", b"node_config", "private_environment_config", b"private_environment_config", "software_config", b"software_config", "web_server_config", b"web_server_config", "web_server_network_access_control", b"web_server_network_access_control", "workloads_config", b"workloads_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["airflow_uri", b"airflow_uri", "dag_gcs_prefix", b"dag_gcs_prefix", "database_config", b"database_config", "encryption_config", b"encryption_config", "environment_size", b"environment_size", "gke_cluster", b"gke_cluster", "maintenance_window", b"maintenance_window", "master_authorized_networks_config", b"master_authorized_networks_config", "node_config", b"node_config", "node_count", b"node_count", "private_environment_config", b"private_environment_config", "software_config", b"software_config", "web_server_config", b"web_server_config", "web_server_network_access_control", b"web_server_network_access_control", "workloads_config", b"workloads_config"]) -> None: ...

global___ComposerEnvironmentXConfig = ComposerEnvironmentXConfig

@typing_extensions.final
class ComposerEnvironmentXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComposerEnvironmentXTimeouts = ComposerEnvironmentXTimeouts

@typing_extensions.final
class ComposerEnvironment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    project: builtins.str
    region: builtins.str
    @property
    def config(self) -> global___ComposerEnvironmentXConfig: ...
    @property
    def timeouts(self) -> global___ComposerEnvironmentXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        config: global___ComposerEnvironmentXConfig | None = ...,
        timeouts: global___ComposerEnvironmentXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["config", b"config", "id", b"id", "labels", b"labels", "name", b"name", "project", b"project", "region", b"region", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> None: ...

global___ComposerEnvironment = ComposerEnvironment



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_region.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cgcp/gcp_compute_region.proto\x12\x1eoak9.tython.gcp.compute_region\x1a\x13shared/shared.proto\"e\n8ComputeRegionAutoscalerXAutoscalingPolicyXCpuUtilization\x12\x19\n\x11predictive_method\x18\x01 \x01(\t\x12\x0e\n\x06target\x18\x02 \x01(\x01\"T\nBComputeRegionAutoscalerXAutoscalingPolicyXLoadBalancingUtilization\x12\x0e\n\x06target\x18\x01 \x01(\x01\"^\n0ComputeRegionAutoscalerXAutoscalingPolicyXMetric\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06target\x18\x02 \x01(\x01\x12\x0c\n\x04type\x18\x03 \x01(\t\"n\nLComputeRegionAutoscalerXAutoscalingPolicyXScaleInControlXMaxScaledInReplicas\x12\r\n\x05\x66ixed\x18\x01 \x01(\x01\x12\x0f\n\x07percent\x18\x02 \x01(\x01\"\xe2\x01\n8ComputeRegionAutoscalerXAutoscalingPolicyXScaleInControl\x12\x17\n\x0ftime_window_sec\x18\x01 \x01(\x01\x12\x8c\x01\n\x16max_scaled_in_replicas\x18\x02 \x01(\x0b\x32l.oak9.tython.gcp.compute_region.ComputeRegionAutoscalerXAutoscalingPolicyXScaleInControlXMaxScaledInReplicas\"\xcb\x01\n:ComputeRegionAutoscalerXAutoscalingPolicyXScalingSchedules\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x10\n\x08\x64isabled\x18\x02 \x01(\x08\x12\x14\n\x0c\x64uration_sec\x18\x03 \x01(\x01\x12\x1d\n\x15min_required_replicas\x18\x04 \x01(\x01\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x10\n\x08schedule\x18\x06 \x01(\t\x12\x11\n\ttime_zone\x18\x07 \x01(\t\"\xc7\x05\n)ComputeRegionAutoscalerXAutoscalingPolicy\x12\x17\n\x0f\x63ooldown_period\x18\x01 \x01(\x01\x12\x14\n\x0cmax_replicas\x18\x02 \x01(\x01\x12\x14\n\x0cmin_replicas\x18\x03 \x01(\x01\x12\x0c\n\x04mode\x18\x04 \x01(\t\x12q\n\x0f\x63pu_utilization\x18\x05 \x01(\x0b\x32X.oak9.tython.gcp.compute_region.ComputeRegionAutoscalerXAutoscalingPolicyXCpuUtilization\x12\x86\x01\n\x1aload_balancing_utilization\x18\x06 \x01(\x0b\x32\x62.oak9.tython.gcp.compute_region.ComputeRegionAutoscalerXAutoscalingPolicyXLoadBalancingUtilization\x12`\n\x06metric\x18\x07 \x03(\x0b\x32P.oak9.tython.gcp.compute_region.ComputeRegionAutoscalerXAutoscalingPolicyXMetric\x12r\n\x10scale_in_control\x18\x08 \x01(\x0b\x32X.oak9.tython.gcp.compute_region.ComputeRegionAutoscalerXAutoscalingPolicyXScaleInControl\x12u\n\x11scaling_schedules\x18\t \x03(\x0b\x32Z.oak9.tython.gcp.compute_region.ComputeRegionAutoscalerXAutoscalingPolicyXScalingSchedules\"R\n ComputeRegionAutoscalerXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x9c\x03\n\x17\x43omputeRegionAutoscaler\x12\x1a\n\x12\x63reation_timestamp\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x11\n\tself_link\x18\x07 \x01(\t\x12\x0e\n\x06target\x18\x08 \x01(\t\x12\x65\n\x12\x61utoscaling_policy\x18\t \x01(\x0b\x32I.oak9.tython.gcp.compute_region.ComputeRegionAutoscalerXAutoscalingPolicy\x12R\n\x08timeouts\x18\n \x01(\x0b\x32@.oak9.tython.gcp.compute_region.ComputeRegionAutoscalerXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xda\x02\n#ComputeRegionBackendServiceXBackend\x12\x16\n\x0e\x62\x61lancing_mode\x18\x01 \x01(\t\x12\x17\n\x0f\x63\x61pacity_scaler\x18\x02 \x01(\x01\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08\x66\x61ilover\x18\x04 \x01(\x08\x12\r\n\x05group\x18\x05 \x01(\t\x12\x17\n\x0fmax_connections\x18\x06 \x01(\x01\x12$\n\x1cmax_connections_per_endpoint\x18\x07 \x01(\x01\x12$\n\x1cmax_connections_per_instance\x18\x08 \x01(\x01\x12\x10\n\x08max_rate\x18\t \x01(\x01\x12\x1d\n\x15max_rate_per_endpoint\x18\n \x01(\x01\x12\x1d\n\x15max_rate_per_instance\x18\x0b \x01(\x01\x12\x17\n\x0fmax_utilization\x18\x0c \x01(\x01\"\xe3\x01\n4ComputeRegionBackendServiceXCdnPolicyXCacheKeyPolicy\x12\x14\n\x0cinclude_host\x18\x01 \x01(\x08\x12\x1d\n\x15include_named_cookies\x18\x02 \x03(\t\x12\x18\n\x10include_protocol\x18\x03 \x01(\x08\x12\x1c\n\x14include_query_string\x18\x04 \x01(\x08\x12\x1e\n\x16query_string_blacklist\x18\x05 \x03(\t\x12\x1e\n\x16query_string_whitelist\x18\x06 \x03(\t\"K\n;ComputeRegionBackendServiceXCdnPolicyXNegativeCachingPolicy\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x01\"\xbe\x03\n%ComputeRegionBackendServiceXCdnPolicy\x12\x12\n\ncache_mode\x18\x01 \x01(\t\x12\x12\n\nclient_ttl\x18\x02 \x01(\x01\x12\x13\n\x0b\x64\x65\x66\x61ult_ttl\x18\x03 \x01(\x01\x12\x0f\n\x07max_ttl\x18\x04 \x01(\x01\x12\x18\n\x10negative_caching\x18\x05 \x01(\x08\x12\x19\n\x11serve_while_stale\x18\x06 \x01(\x01\x12$\n\x1csigned_url_cache_max_age_sec\x18\x07 \x01(\x01\x12n\n\x10\x63\x61\x63he_key_policy\x18\x08 \x01(\x0b\x32T.oak9.tython.gcp.compute_region.ComputeRegionBackendServiceXCdnPolicyXCacheKeyPolicy\x12|\n\x17negative_caching_policy\x18\t \x03(\x0b\x32[.oak9.tython.gcp.compute_region.ComputeRegionBackendServiceXCdnPolicyXNegativeCachingPolicy\"\xb4\x01\n+ComputeRegionBackendServiceXCircuitBreakers\x12\x17\n\x0fmax_connections\x18\x01 \x01(\x01\x12\x1c\n\x14max_pending_requests\x18\x02 \x01(\x01\x12\x14\n\x0cmax_requests\x18\x03 \x01(\x01\x12#\n\x1bmax_requests_per_connection\x18\x04 \x01(\x01\x12\x13\n\x0bmax_retries\x18\x05 \x01(\x01\"[\n9ComputeRegionBackendServiceXConsistentHashXHttpCookieXTtl\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\x01\"\xbb\x01\n5ComputeRegionBackendServiceXConsistentHashXHttpCookie\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x66\n\x03ttl\x18\x03 \x01(\x0b\x32Y.oak9.tython.gcp.compute_region.ComputeRegionBackendServiceXConsistentHashXHttpCookieXTtl\"\xcd\x01\n*ComputeRegionBackendServiceXConsistentHash\x12\x18\n\x10http_header_name\x18\x01 \x01(\t\x12\x19\n\x11minimum_ring_size\x18\x02 \x01(\x01\x12j\n\x0bhttp_cookie\x18\x03 \x01(\x0b\x32U.oak9.tython.gcp.compute_region.ComputeRegionBackendServiceXConsistentHashXHttpCookie\"\x95\x01\n*ComputeRegionBackendServiceXFailoverPolicy\x12,\n$disable_connection_drain_on_failover\x18\x01 \x01(\x08\x12!\n\x19\x64rop_traffic_if_unhealthy\x18\x02 \x01(\x08\x12\x16\n\x0e\x66\x61ilover_ratio\x18\x03 \x01(\x01\"~\n\x1f\x43omputeRegionBackendServiceXIap\x12\x18\n\x10oauth2_client_id\x18\x01 \x01(\t\x12\x1c\n\x14oauth2_client_secret\x18\x02 \x01(\t\x12#\n\x1boauth2_client_secret_sha256\x18\x03 \x01(\t\"L\n%ComputeRegionBackendServiceXLogConfig\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\x12\x13\n\x0bsample_rate\x18\x02 \x01(\x01\"_\n=ComputeRegionBackendServiceXOutlierDetectionXBaseEjectionTime\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\x01\"W\n5ComputeRegionBackendServiceXOutlierDetectionXInterval\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\x01\"\xd2\x04\n,ComputeRegionBackendServiceXOutlierDetection\x12\x1a\n\x12\x63onsecutive_errors\x18\x01 \x01(\x01\x12#\n\x1b\x63onsecutive_gateway_failure\x18\x02 \x01(\x01\x12$\n\x1c\x65nforcing_consecutive_errors\x18\x03 \x01(\x01\x12-\n%enforcing_consecutive_gateway_failure\x18\x04 \x01(\x01\x12\x1e\n\x16\x65nforcing_success_rate\x18\x05 \x01(\x01\x12\x1c\n\x14max_ejection_percent\x18\x06 \x01(\x01\x12\"\n\x1asuccess_rate_minimum_hosts\x18\x07 \x01(\x01\x12#\n\x1bsuccess_rate_request_volume\x18\x08 \x01(\x01\x12!\n\x19success_rate_stdev_factor\x18\t \x01(\x01\x12y\n\x12\x62\x61se_ejection_time\x18\n \x01(\x0b\x32].oak9.tython.gcp.compute_region.ComputeRegionBackendServiceXOutlierDetectionXBaseEjectionTime\x12g\n\x08interval\x18\x0b \x01(\x0b\x32U.oak9.tython.gcp.compute_region.ComputeRegionBackendServiceXOutlierDetectionXInterval\"V\n$ComputeRegionBackendServiceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xcb\n\n\x1b\x43omputeRegionBackendService\x12\x1f\n\x17\x61\x66\x66inity_cookie_ttl_sec\x18\x01 \x01(\x01\x12\'\n\x1f\x63onnection_draining_timeout_sec\x18\x02 \x01(\x01\x12\x1a\n\x12\x63reation_timestamp\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x12\n\nenable_cdn\x18\x05 \x01(\x08\x12\x13\n\x0b\x66ingerprint\x18\x06 \x01(\t\x12\x15\n\rhealth_checks\x18\x07 \x03(\t\x12\n\n\x02id\x18\x08 \x01(\t\x12\x1d\n\x15load_balancing_scheme\x18\t \x01(\t\x12\x1a\n\x12locality_lb_policy\x18\n \x01(\t\x12\x0c\n\x04name\x18\x0b \x01(\t\x12\x0f\n\x07network\x18\x0c \x01(\t\x12\x11\n\tport_name\x18\r \x01(\t\x12\x0f\n\x07project\x18\x0e \x01(\t\x12\x10\n\x08protocol\x18\x0f \x01(\t\x12\x0e\n\x06region\x18\x10 \x01(\t\x12\x11\n\tself_link\x18\x11 \x01(\t\x12\x18\n\x10session_affinity\x18\x12 \x01(\t\x12\x13\n\x0btimeout_sec\x18\x13 \x01(\x01\x12T\n\x07\x62\x61\x63kend\x18\x14 \x03(\x0b\x32\x43.oak9.tython.gcp.compute_region.ComputeRegionBackendServiceXBackend\x12Y\n\ncdn_policy\x18\x15 \x01(\x0b\x32\x45.oak9.tython.gcp.compute_region.ComputeRegionBackendServiceXCdnPolicy\x12\x65\n\x10\x63ircuit_breakers\x18\x16 \x01(\x0b\x32K.oak9.tython.gcp.compute_region.ComputeRegionBackendServiceXCircuitBreakers\x12\x63\n\x0f\x63onsistent_hash\x18\x17 \x01(\x0b\x32J.oak9.tython.gcp.compute_region.ComputeRegionBackendServiceXConsistentHash\x12\x63\n\x0f\x66\x61ilover_policy\x18\x18 \x01(\x0b\x32J.oak9.tython.gcp.compute_region.ComputeRegionBackendServiceXFailoverPolicy\x12L\n\x03iap\x18\x19 \x01(\x0b\x32?.oak9.tython.gcp.compute_region.ComputeRegionBackendServiceXIap\x12Y\n\nlog_config\x18\x1a \x01(\x0b\x32\x45.oak9.tython.gcp.compute_region.ComputeRegionBackendServiceXLogConfig\x12g\n\x11outlier_detection\x18\x1b \x01(\x0b\x32L.oak9.tython.gcp.compute_region.ComputeRegionBackendServiceXOutlierDetection\x12V\n\x08timeouts\x18\x1c \x01(\x0b\x32\x44.oak9.tython.gcp.compute_region.ComputeRegionBackendServiceXTimeouts\x12\x37\n\rresource_info\x18\x1d \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\\\n#ComputeRegionDiskXDiskEncryptionKey\x12\x14\n\x0ckms_key_name\x18\x01 \x01(\t\x12\x0f\n\x07raw_key\x18\x02 \x01(\t\x12\x0e\n\x06sha256\x18\x03 \x01(\t\"P\n-ComputeRegionDiskXSourceSnapshotEncryptionKey\x12\x0f\n\x07raw_key\x18\x01 \x01(\t\x12\x0e\n\x06sha256\x18\x02 \x01(\t\"L\n\x1a\x43omputeRegionDiskXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xdc\x06\n\x11\x43omputeRegionDisk\x12\x1a\n\x12\x63reation_timestamp\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x19\n\x11label_fingerprint\x18\x04 \x01(\t\x12M\n\x06labels\x18\x05 \x03(\x0b\x32=.oak9.tython.gcp.compute_region.ComputeRegionDisk.LabelsEntry\x12\x1d\n\x15last_attach_timestamp\x18\x06 \x01(\t\x12\x1d\n\x15last_detach_timestamp\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12!\n\x19physical_block_size_bytes\x18\t \x01(\x01\x12\x0f\n\x07project\x18\n \x01(\t\x12\x0e\n\x06region\x18\x0b \x01(\t\x12\x15\n\rreplica_zones\x18\x0c \x03(\t\x12\x11\n\tself_link\x18\r \x01(\t\x12\x0c\n\x04size\x18\x0e \x01(\x01\x12\x10\n\x08snapshot\x18\x0f \x01(\t\x12\x1a\n\x12source_snapshot_id\x18\x10 \x01(\t\x12\x0c\n\x04type\x18\x11 \x01(\t\x12\r\n\x05users\x18\x12 \x03(\t\x12`\n\x13\x64isk_encryption_key\x18\x13 \x01(\x0b\x32\x43.oak9.tython.gcp.compute_region.ComputeRegionDiskXDiskEncryptionKey\x12u\n\x1esource_snapshot_encryption_key\x18\x14 \x01(\x0b\x32M.oak9.tython.gcp.compute_region.ComputeRegionDiskXSourceSnapshotEncryptionKey\x12L\n\x08timeouts\x18\x15 \x01(\x0b\x32:.oak9.tython.gcp.compute_region.ComputeRegionDiskXTimeouts\x12\x37\n\rresource_info\x18\x16 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"_\n%ComputeRegionDiskIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x98\x02\n\x1b\x43omputeRegionDiskIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12X\n\tcondition\x18\x08 \x01(\x0b\x32\x45.oak9.tython.gcp.compute_region.ComputeRegionDiskIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"^\n$ComputeRegionDiskIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x95\x02\n\x1a\x43omputeRegionDiskIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12W\n\tcondition\x18\x08 \x01(\x0b\x32\x44.oak9.tython.gcp.compute_region.ComputeRegionDiskIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb3\x01\n\x1a\x43omputeRegionDiskIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"T\n2ComputeRegionDiskResourcePolicyAttachmentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\x93\x02\n)ComputeRegionDiskResourcePolicyAttachment\x12\x0c\n\x04\x64isk\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0e\n\x06region\x18\x05 \x01(\t\x12\x64\n\x08timeouts\x18\x06 \x01(\x0b\x32R.oak9.tython.gcp.compute_region.ComputeRegionDiskResourcePolicyAttachmentXTimeouts\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x82\x01\n(ComputeRegionHealthCheckXGrpcHealthCheck\x12\x19\n\x11grpc_service_name\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x01\x12\x11\n\tport_name\x18\x03 \x01(\t\x12\x1a\n\x12port_specification\x18\x04 \x01(\t\"\xb4\x01\n)ComputeRegionHealthCheckXHttp2HealthCheck\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x01\x12\x11\n\tport_name\x18\x03 \x01(\t\x12\x1a\n\x12port_specification\x18\x04 \x01(\t\x12\x14\n\x0cproxy_header\x18\x05 \x01(\t\x12\x14\n\x0crequest_path\x18\x06 \x01(\t\x12\x10\n\x08response\x18\x07 \x01(\t\"\xb3\x01\n(ComputeRegionHealthCheckXHttpHealthCheck\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x01\x12\x11\n\tport_name\x18\x03 \x01(\t\x12\x1a\n\x12port_specification\x18\x04 \x01(\t\x12\x14\n\x0cproxy_header\x18\x05 \x01(\t\x12\x14\n\x0crequest_path\x18\x06 \x01(\t\x12\x10\n\x08response\x18\x07 \x01(\t\"\xb4\x01\n)ComputeRegionHealthCheckXHttpsHealthCheck\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x01\x12\x11\n\tport_name\x18\x03 \x01(\t\x12\x1a\n\x12port_specification\x18\x04 \x01(\t\x12\x14\n\x0cproxy_header\x18\x05 \x01(\t\x12\x14\n\x0crequest_path\x18\x06 \x01(\t\x12\x10\n\x08response\x18\x07 \x01(\t\"4\n\"ComputeRegionHealthCheckXLogConfig\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\"\x9f\x01\n\'ComputeRegionHealthCheckXSslHealthCheck\x12\x0c\n\x04port\x18\x01 \x01(\x01\x12\x11\n\tport_name\x18\x02 \x01(\t\x12\x1a\n\x12port_specification\x18\x03 \x01(\t\x12\x14\n\x0cproxy_header\x18\x04 \x01(\t\x12\x0f\n\x07request\x18\x05 \x01(\t\x12\x10\n\x08response\x18\x06 \x01(\t\"\x9f\x01\n\'ComputeRegionHealthCheckXTcpHealthCheck\x12\x0c\n\x04port\x18\x01 \x01(\x01\x12\x11\n\tport_name\x18\x02 \x01(\t\x12\x1a\n\x12port_specification\x18\x03 \x01(\t\x12\x14\n\x0cproxy_header\x18\x04 \x01(\t\x12\x0f\n\x07request\x18\x05 \x01(\t\x12\x10\n\x08response\x18\x06 \x01(\t\"S\n!ComputeRegionHealthCheckXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xd4\x08\n\x18\x43omputeRegionHealthCheck\x12\x1a\n\x12\x63heck_interval_sec\x18\x01 \x01(\x01\x12\x1a\n\x12\x63reation_timestamp\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x19\n\x11healthy_threshold\x18\x04 \x01(\x01\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x0e\n\x06region\x18\x08 \x01(\t\x12\x11\n\tself_link\x18\t \x01(\t\x12\x13\n\x0btimeout_sec\x18\n \x01(\x01\x12\x0c\n\x04type\x18\x0b \x01(\t\x12\x1b\n\x13unhealthy_threshold\x18\x0c \x01(\x01\x12\x63\n\x11grpc_health_check\x18\r \x01(\x0b\x32H.oak9.tython.gcp.compute_region.ComputeRegionHealthCheckXGrpcHealthCheck\x12\x65\n\x12http2_health_check\x18\x0e \x01(\x0b\x32I.oak9.tython.gcp.compute_region.ComputeRegionHealthCheckXHttp2HealthCheck\x12\x63\n\x11http_health_check\x18\x0f \x01(\x0b\x32H.oak9.tython.gcp.compute_region.ComputeRegionHealthCheckXHttpHealthCheck\x12\x65\n\x12https_health_check\x18\x10 \x01(\x0b\x32I.oak9.tython.gcp.compute_region.ComputeRegionHealthCheckXHttpsHealthCheck\x12V\n\nlog_config\x18\x11 \x01(\x0b\x32\x42.oak9.tython.gcp.compute_region.ComputeRegionHealthCheckXLogConfig\x12\x61\n\x10ssl_health_check\x18\x12 \x01(\x0b\x32G.oak9.tython.gcp.compute_region.ComputeRegionHealthCheckXSslHealthCheck\x12\x61\n\x10tcp_health_check\x18\x13 \x01(\x0b\x32G.oak9.tython.gcp.compute_region.ComputeRegionHealthCheckXTcpHealthCheck\x12S\n\x08timeouts\x18\x14 \x01(\x0b\x32\x41.oak9.tython.gcp.compute_region.ComputeRegionHealthCheckXTimeouts\x12\x37\n\rresource_info\x18\x15 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"h\n5ComputeRegionInstanceGroupManagerXAutoHealingPolicies\x12\x14\n\x0chealth_check\x18\x01 \x01(\t\x12\x19\n\x11initial_delay_sec\x18\x02 \x01(\x01\"I\n+ComputeRegionInstanceGroupManagerXNamedPort\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x01\"Z\n.ComputeRegionInstanceGroupManagerXStatefulDisk\x12\x13\n\x0b\x64\x65lete_rule\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\"\\\n*ComputeRegionInstanceGroupManagerXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb4\x02\n.ComputeRegionInstanceGroupManagerXUpdatePolicy\x12$\n\x1cinstance_redistribution_type\x18\x01 \x01(\t\x12\x17\n\x0fmax_surge_fixed\x18\x02 \x01(\x01\x12\x19\n\x11max_surge_percent\x18\x03 \x01(\x01\x12\x1d\n\x15max_unavailable_fixed\x18\x04 \x01(\x01\x12\x1f\n\x17max_unavailable_percent\x18\x05 \x01(\x01\x12\x16\n\x0eminimal_action\x18\x06 \x01(\t\x12&\n\x1emost_disruptive_allowed_action\x18\x07 \x01(\t\x12\x1a\n\x12replacement_method\x18\x08 \x01(\t\x12\x0c\n\x04type\x18\t \x01(\t\"V\n4ComputeRegionInstanceGroupManagerXVersionXTargetSize\x12\r\n\x05\x66ixed\x18\x01 \x01(\x01\x12\x0f\n\x07percent\x18\x02 \x01(\x01\"\xbf\x01\n)ComputeRegionInstanceGroupManagerXVersion\x12\x19\n\x11instance_template\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12i\n\x0btarget_size\x18\x03 \x01(\x0b\x32T.oak9.tython.gcp.compute_region.ComputeRegionInstanceGroupManagerXVersionXTargetSize\"\xac\t\n!ComputeRegionInstanceGroupManager\x12\x1a\n\x12\x62\x61se_instance_name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12(\n distribution_policy_target_shape\x18\x03 \x01(\t\x12!\n\x19\x64istribution_policy_zones\x18\x04 \x03(\t\x12\x13\n\x0b\x66ingerprint\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x16\n\x0einstance_group\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x0f\n\x07project\x18\t \x01(\t\x12\x0e\n\x06region\x18\n \x01(\t\x12\x11\n\tself_link\x18\x0b \x01(\t\x12]\n\x06status\x18\x0c \x03(\x0b\x32M.oak9.tython.gcp.compute_region.ComputeRegionInstanceGroupManager.StatusEntry\x12\x14\n\x0ctarget_pools\x18\r \x03(\t\x12\x13\n\x0btarget_size\x18\x0e \x01(\x01\x12\x1a\n\x12wait_for_instances\x18\x0f \x01(\x08\x12!\n\x19wait_for_instances_status\x18\x10 \x01(\t\x12t\n\x15\x61uto_healing_policies\x18\x11 \x01(\x0b\x32U.oak9.tython.gcp.compute_region.ComputeRegionInstanceGroupManagerXAutoHealingPolicies\x12_\n\nnamed_port\x18\x12 \x03(\x0b\x32K.oak9.tython.gcp.compute_region.ComputeRegionInstanceGroupManagerXNamedPort\x12\x65\n\rstateful_disk\x18\x13 \x03(\x0b\x32N.oak9.tython.gcp.compute_region.ComputeRegionInstanceGroupManagerXStatefulDisk\x12\\\n\x08timeouts\x18\x14 \x01(\x0b\x32J.oak9.tython.gcp.compute_region.ComputeRegionInstanceGroupManagerXTimeouts\x12\x65\n\rupdate_policy\x18\x15 \x01(\x0b\x32N.oak9.tython.gcp.compute_region.ComputeRegionInstanceGroupManagerXUpdatePolicy\x12Z\n\x07version\x18\x16 \x03(\x0b\x32I.oak9.tython.gcp.compute_region.ComputeRegionInstanceGroupManagerXVersion\x12\x37\n\rresource_info\x18\x17 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bStatusEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"a\n+ComputeRegionNetworkEndpointGroupXAppEngine\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x10\n\x08url_mask\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\"U\n/ComputeRegionNetworkEndpointGroupXCloudFunction\x12\x10\n\x08\x66unction\x18\x01 \x01(\t\x12\x10\n\x08url_mask\x18\x02 \x01(\t\"\\\n*ComputeRegionNetworkEndpointGroupXCloudRun\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\x12\x10\n\x08url_mask\x18\x03 \x01(\t\"L\n*ComputeRegionNetworkEndpointGroupXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xa6\x05\n!ComputeRegionNetworkEndpointGroup\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07network\x18\x04 \x01(\t\x12\x1d\n\x15network_endpoint_type\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x1a\n\x12psc_target_service\x18\x07 \x01(\t\x12\x0e\n\x06region\x18\x08 \x01(\t\x12\x11\n\tself_link\x18\t \x01(\t\x12\x12\n\nsubnetwork\x18\n \x01(\t\x12_\n\napp_engine\x18\x0b \x01(\x0b\x32K.oak9.tython.gcp.compute_region.ComputeRegionNetworkEndpointGroupXAppEngine\x12g\n\x0e\x63loud_function\x18\x0c \x01(\x0b\x32O.oak9.tython.gcp.compute_region.ComputeRegionNetworkEndpointGroupXCloudFunction\x12]\n\tcloud_run\x18\r \x01(\x0b\x32J.oak9.tython.gcp.compute_region.ComputeRegionNetworkEndpointGroupXCloudRun\x12\\\n\x08timeouts\x18\x0e \x01(\x0b\x32J.oak9.tython.gcp.compute_region.ComputeRegionNetworkEndpointGroupXTimeouts\x12\x37\n\rresource_info\x18\x0f \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"|\n2ComputeRegionPerInstanceConfigXPreservedStateXDisk\x12\x13\n\x0b\x64\x65lete_rule\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12\x0c\n\x04mode\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\"\xb1\x02\n-ComputeRegionPerInstanceConfigXPreservedState\x12m\n\x08metadata\x18\x01 \x03(\x0b\x32[.oak9.tython.gcp.compute_region.ComputeRegionPerInstanceConfigXPreservedState.MetadataEntry\x12`\n\x04\x64isk\x18\x02 \x03(\x0b\x32R.oak9.tython.gcp.compute_region.ComputeRegionPerInstanceConfigXPreservedStateXDisk\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Y\n\'ComputeRegionPerInstanceConfigXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xe8\x03\n\x1e\x43omputeRegionPerInstanceConfig\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\x0eminimal_action\x18\x02 \x01(\t\x12&\n\x1emost_disruptive_allowed_action\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12%\n\x1dregion_instance_group_manager\x18\x07 \x01(\t\x12(\n remove_instance_state_on_destroy\x18\x08 \x01(\x08\x12\x66\n\x0fpreserved_state\x18\t \x01(\x0b\x32M.oak9.tython.gcp.compute_region.ComputeRegionPerInstanceConfigXPreservedState\x12Y\n\x08timeouts\x18\n \x01(\x0b\x32G.oak9.tython.gcp.compute_region.ComputeRegionPerInstanceConfigXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"F\n$ComputeRegionSslCertificateXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\x84\x03\n\x1b\x43omputeRegionSslCertificate\x12\x13\n\x0b\x63\x65rtificate\x18\x01 \x01(\t\x12\x16\n\x0e\x63\x65rtificate_id\x18\x02 \x01(\x01\x12\x1a\n\x12\x63reation_timestamp\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x13\n\x0bname_prefix\x18\x07 \x01(\t\x12\x13\n\x0bprivate_key\x18\x08 \x01(\t\x12\x0f\n\x07project\x18\t \x01(\t\x12\x0e\n\x06region\x18\n \x01(\t\x12\x11\n\tself_link\x18\x0b \x01(\t\x12V\n\x08timeouts\x18\x0c \x01(\x0b\x32\x44.oak9.tython.gcp.compute_region.ComputeRegionSslCertificateXTimeouts\x12\x37\n\rresource_info\x18\r \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"W\n%ComputeRegionTargetHttpProxyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xd2\x02\n\x1c\x43omputeRegionTargetHttpProxy\x12\x1a\n\x12\x63reation_timestamp\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x10\n\x08proxy_id\x18\x06 \x01(\x01\x12\x0e\n\x06region\x18\x07 \x01(\t\x12\x11\n\tself_link\x18\x08 \x01(\t\x12\x0f\n\x07url_map\x18\t \x01(\t\x12W\n\x08timeouts\x18\n \x01(\x0b\x32\x45.oak9.tython.gcp.compute_region.ComputeRegionTargetHttpProxyXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"X\n&ComputeRegionTargetHttpsProxyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xee\x02\n\x1d\x43omputeRegionTargetHttpsProxy\x12\x1a\n\x12\x63reation_timestamp\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x10\n\x08proxy_id\x18\x06 \x01(\x01\x12\x0e\n\x06region\x18\x07 \x01(\t\x12\x11\n\tself_link\x18\x08 \x01(\t\x12\x18\n\x10ssl_certificates\x18\t \x03(\t\x12\x0f\n\x07url_map\x18\n \x01(\t\x12X\n\x08timeouts\x18\x0b \x01(\x0b\x32\x46.oak9.tython.gcp.compute_region.ComputeRegionTargetHttpsProxyXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbc\x01\n&ComputeRegionUrlMapXDefaultUrlRedirect\x12\x15\n\rhost_redirect\x18\x01 \x01(\t\x12\x16\n\x0ehttps_redirect\x18\x02 \x01(\x08\x12\x15\n\rpath_redirect\x18\x03 \x01(\t\x12\x17\n\x0fprefix_redirect\x18\x04 \x01(\t\x12\x1e\n\x16redirect_response_code\x18\x05 \x01(\t\x12\x13\n\x0bstrip_query\x18\x06 \x01(\x08\"X\n\x1c\x43omputeRegionUrlMapXHostRule\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\r\n\x05hosts\x18\x02 \x03(\t\x12\x14\n\x0cpath_matcher\x18\x03 \x01(\t\"\xc8\x01\n2ComputeRegionUrlMapXPathMatcherXDefaultUrlRedirect\x12\x15\n\rhost_redirect\x18\x01 \x01(\t\x12\x16\n\x0ehttps_redirect\x18\x02 \x01(\x08\x12\x15\n\rpath_redirect\x18\x03 \x01(\t\x12\x17\n\x0fprefix_redirect\x18\x04 \x01(\t\x12\x1e\n\x16redirect_response_code\x18\x05 \x01(\t\x12\x13\n\x0bstrip_query\x18\x06 \x01(\x08\"\xfa\x01\n?ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXCorsPolicy\x12\x19\n\x11\x61llow_credentials\x18\x01 \x01(\x08\x12\x15\n\rallow_headers\x18\x02 \x03(\t\x12\x15\n\rallow_methods\x18\x03 \x03(\t\x12\x1c\n\x14\x61llow_origin_regexes\x18\x04 \x03(\t\x12\x15\n\rallow_origins\x18\x05 \x03(\t\x12\x10\n\x08\x64isabled\x18\x06 \x01(\x08\x12\x16\n\x0e\x65xpose_headers\x18\x07 \x03(\t\x12\x0f\n\x07max_age\x18\x08 \x01(\x01\"z\nOComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXAbort\x12\x13\n\x0bhttp_status\x18\x01 \x01(\x01\x12\x12\n\npercentage\x18\x02 \x01(\x01\"|\nZComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelayXFixedDelay\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"\xf7\x01\nOComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelay\x12\x12\n\npercentage\x18\x01 \x01(\x01\x12\x8f\x01\n\x0b\x66ixed_delay\x18\x02 \x01(\x0b\x32z.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelayXFixedDelay\"\xcb\x02\nIComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicy\x12~\n\x05\x61\x62ort\x18\x01 \x01(\x0b\x32o.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXAbort\x12~\n\x05\x64\x65lay\x18\x02 \x01(\x0b\x32o.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelay\"c\nHComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXRequestMirrorPolicy\x12\x17\n\x0f\x62\x61\x63kend_service\x18\x01 \x01(\t\"p\nNComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicyXPerTryTimeout\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"\xfb\x01\n@ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicy\x12\x13\n\x0bnum_retries\x18\x01 \x01(\x01\x12\x18\n\x10retry_conditions\x18\x02 \x03(\t\x12\x87\x01\n\x0fper_try_timeout\x18\x03 \x01(\x0b\x32n.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicyXPerTryTimeout\"^\n<ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXTimeout\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"t\n?ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXUrlRewrite\x12\x14\n\x0chost_rewrite\x18\x01 \x01(\t\x12\x1b\n\x13path_prefix_rewrite\x18\x02 \x01(\t\"\xab\x01\nmComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\xac\x01\nnComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\x86\x04\nYComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderAction\x12!\n\x19request_headers_to_remove\x18\x01 \x03(\t\x12\"\n\x1aresponse_headers_to_remove\x18\x02 \x03(\t\x12\xae\x01\n\x16request_headers_to_add\x18\x03 \x03(\x0b\x32\x8d\x01.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd\x12\xb0\x01\n\x17response_headers_to_add\x18\x04 \x03(\x0b\x32\x8e\x01.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd\"\x8a\x02\nLComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServices\x12\x17\n\x0f\x62\x61\x63kend_service\x18\x01 \x01(\t\x12\x0e\n\x06weight\x18\x02 \x01(\x01\x12\x90\x01\n\rheader_action\x18\x03 \x01(\x0b\x32y.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderAction\"\xb1\x07\n4ComputeRegionUrlMapXPathMatcherXPathRuleXRouteAction\x12t\n\x0b\x63ors_policy\x18\x01 \x01(\x0b\x32_.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXCorsPolicy\x12\x89\x01\n\x16\x66\x61ult_injection_policy\x18\x02 \x01(\x0b\x32i.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicy\x12\x87\x01\n\x15request_mirror_policy\x18\x03 \x01(\x0b\x32h.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXRequestMirrorPolicy\x12v\n\x0cretry_policy\x18\x04 \x01(\x0b\x32`.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicy\x12m\n\x07timeout\x18\x05 \x01(\x0b\x32\\.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXTimeout\x12t\n\x0burl_rewrite\x18\x06 \x01(\x0b\x32_.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXUrlRewrite\x12\x8f\x01\n\x19weighted_backend_services\x18\x07 \x03(\x0b\x32l.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServices\"\xca\x01\n4ComputeRegionUrlMapXPathMatcherXPathRuleXUrlRedirect\x12\x15\n\rhost_redirect\x18\x01 \x01(\t\x12\x16\n\x0ehttps_redirect\x18\x02 \x01(\x08\x12\x15\n\rpath_redirect\x18\x03 \x01(\t\x12\x17\n\x0fprefix_redirect\x18\x04 \x01(\t\x12\x1e\n\x16redirect_response_code\x18\x05 \x01(\t\x12\x13\n\x0bstrip_query\x18\x06 \x01(\x08\"\xa2\x02\n(ComputeRegionUrlMapXPathMatcherXPathRule\x12\r\n\x05paths\x18\x01 \x03(\t\x12\x0f\n\x07service\x18\x02 \x01(\t\x12j\n\x0croute_action\x18\x03 \x01(\x0b\x32T.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXPathRuleXRouteAction\x12j\n\x0curl_redirect\x18\x04 \x01(\x0b\x32T.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXPathRuleXUrlRedirect\"\x89\x01\nKComputeRegionUrlMapXPathMatcherXRouteRulesXHeaderActionXRequestHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\x8a\x01\nLComputeRegionUrlMapXPathMatcherXRouteRulesXHeaderActionXResponseHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\x9e\x03\n7ComputeRegionUrlMapXPathMatcherXRouteRulesXHeaderAction\x12!\n\x19request_headers_to_remove\x18\x01 \x03(\t\x12\"\n\x1aresponse_headers_to_remove\x18\x02 \x03(\t\x12\x8b\x01\n\x16request_headers_to_add\x18\x03 \x03(\x0b\x32k.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXRouteRulesXHeaderActionXRequestHeadersToAdd\x12\x8d\x01\n\x17response_headers_to_add\x18\x04 \x03(\x0b\x32l.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXRouteRulesXHeaderActionXResponseHeadersToAdd\"x\nNComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatchesXRangeMatch\x12\x11\n\trange_end\x18\x01 \x01(\x01\x12\x13\n\x0brange_start\x18\x02 \x01(\x01\"\xe3\x02\nCComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatches\x12\x13\n\x0b\x65xact_match\x18\x01 \x01(\t\x12\x13\n\x0bheader_name\x18\x02 \x01(\t\x12\x14\n\x0cinvert_match\x18\x03 \x01(\x08\x12\x14\n\x0cprefix_match\x18\x04 \x01(\t\x12\x15\n\rpresent_match\x18\x05 \x01(\x08\x12\x13\n\x0bregex_match\x18\x06 \x01(\t\x12\x14\n\x0csuffix_match\x18\x07 \x01(\t\x12\x83\x01\n\x0brange_match\x18\x08 \x01(\x0b\x32n.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatchesXRangeMatch\"q\nRComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFiltersXFilterLabels\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xf2\x01\nEComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFilters\x12\x1d\n\x15\x66ilter_match_criteria\x18\x01 \x01(\t\x12\x89\x01\n\rfilter_labels\x18\x02 \x03(\x0b\x32r.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFiltersXFilterLabels\"\x9c\x01\nKComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXQueryParameterMatches\x12\x13\n\x0b\x65xact_match\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rpresent_match\x18\x03 \x01(\x08\x12\x13\n\x0bregex_match\x18\x04 \x01(\t\"\x9d\x04\n5ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRules\x12\x17\n\x0f\x66ull_path_match\x18\x01 \x01(\t\x12\x13\n\x0bignore_case\x18\x02 \x01(\x08\x12\x14\n\x0cprefix_match\x18\x03 \x01(\t\x12\x13\n\x0bregex_match\x18\x04 \x01(\t\x12{\n\x0eheader_matches\x18\x05 \x03(\x0b\x32\x63.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatches\x12\x7f\n\x10metadata_filters\x18\x06 \x03(\x0b\x32\x65.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFilters\x12\x8c\x01\n\x17query_parameter_matches\x18\x07 \x03(\x0b\x32k.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRulesXQueryParameterMatches\"\xfc\x01\nAComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXCorsPolicy\x12\x19\n\x11\x61llow_credentials\x18\x01 \x01(\x08\x12\x15\n\rallow_headers\x18\x02 \x03(\t\x12\x15\n\rallow_methods\x18\x03 \x03(\t\x12\x1c\n\x14\x61llow_origin_regexes\x18\x04 \x03(\t\x12\x15\n\rallow_origins\x18\x05 \x03(\t\x12\x10\n\x08\x64isabled\x18\x06 \x01(\x08\x12\x16\n\x0e\x65xpose_headers\x18\x07 \x03(\t\x12\x0f\n\x07max_age\x18\x08 \x01(\x01\"|\nQComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXAbort\x12\x13\n\x0bhttp_status\x18\x01 \x01(\x01\x12\x12\n\npercentage\x18\x02 \x01(\x01\"~\n\\ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelayXFixedDelay\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"\xfb\x01\nQComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelay\x12\x12\n\npercentage\x18\x01 \x01(\x01\x12\x91\x01\n\x0b\x66ixed_delay\x18\x02 \x01(\x0b\x32|.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelayXFixedDelay\"\xd3\x02\nKComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicy\x12\x80\x01\n\x05\x61\x62ort\x18\x01 \x01(\x0b\x32q.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXAbort\x12\x80\x01\n\x05\x64\x65lay\x18\x02 \x01(\x0b\x32q.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelay\"e\nJComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXRequestMirrorPolicy\x12\x17\n\x0f\x62\x61\x63kend_service\x18\x01 \x01(\t\"r\nPComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicyXPerTryTimeout\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"\xff\x01\nBComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicy\x12\x13\n\x0bnum_retries\x18\x01 \x01(\x01\x12\x18\n\x10retry_conditions\x18\x02 \x03(\t\x12\x89\x01\n\x0fper_try_timeout\x18\x03 \x01(\x0b\x32p.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicyXPerTryTimeout\"`\n>ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXTimeout\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"v\nAComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXUrlRewrite\x12\x14\n\x0chost_rewrite\x18\x01 \x01(\t\x12\x1b\n\x13path_prefix_rewrite\x18\x02 \x01(\t\"\xad\x01\noComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\xae\x01\npComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\x8c\x04\n[ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderAction\x12!\n\x19request_headers_to_remove\x18\x01 \x03(\t\x12\"\n\x1aresponse_headers_to_remove\x18\x02 \x03(\t\x12\xb0\x01\n\x16request_headers_to_add\x18\x03 \x03(\x0b\x32\x8f\x01.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd\x12\xb2\x01\n\x17response_headers_to_add\x18\x04 \x03(\x0b\x32\x90\x01.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd\"\x8e\x02\nNComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServices\x12\x17\n\x0f\x62\x61\x63kend_service\x18\x01 \x01(\t\x12\x0e\n\x06weight\x18\x02 \x01(\x01\x12\x92\x01\n\rheader_action\x18\x03 \x01(\x0b\x32{.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderAction\"\xc1\x07\n6ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteAction\x12v\n\x0b\x63ors_policy\x18\x01 \x01(\x0b\x32\x61.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXCorsPolicy\x12\x8b\x01\n\x16\x66\x61ult_injection_policy\x18\x02 \x01(\x0b\x32k.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicy\x12\x89\x01\n\x15request_mirror_policy\x18\x03 \x01(\x0b\x32j.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXRequestMirrorPolicy\x12x\n\x0cretry_policy\x18\x04 \x01(\x0b\x32\x62.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicy\x12o\n\x07timeout\x18\x05 \x01(\x0b\x32^.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXTimeout\x12v\n\x0burl_rewrite\x18\x06 \x01(\x0b\x32\x61.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXUrlRewrite\x12\x91\x01\n\x19weighted_backend_services\x18\x07 \x03(\x0b\x32n.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServices\"\xcc\x01\n6ComputeRegionUrlMapXPathMatcherXRouteRulesXUrlRedirect\x12\x15\n\rhost_redirect\x18\x01 \x01(\t\x12\x16\n\x0ehttps_redirect\x18\x02 \x01(\x08\x12\x15\n\rpath_redirect\x18\x03 \x01(\t\x12\x17\n\x0fprefix_redirect\x18\x04 \x01(\t\x12\x1e\n\x16redirect_response_code\x18\x05 \x01(\t\x12\x13\n\x0bstrip_query\x18\x06 \x01(\x08\"\x87\x04\n*ComputeRegionUrlMapXPathMatcherXRouteRules\x12\x10\n\x08priority\x18\x01 \x01(\x01\x12\x0f\n\x07service\x18\x02 \x01(\t\x12n\n\rheader_action\x18\x03 \x01(\x0b\x32W.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXRouteRulesXHeaderAction\x12j\n\x0bmatch_rules\x18\x04 \x03(\x0b\x32U.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXRouteRulesXMatchRules\x12l\n\x0croute_action\x18\x05 \x01(\x0b\x32V.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXRouteRulesXRouteAction\x12l\n\x0curl_redirect\x18\x06 \x01(\x0b\x32V.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXRouteRulesXUrlRedirect\"\x8d\x03\n\x1f\x43omputeRegionUrlMapXPathMatcher\x12\x17\n\x0f\x64\x65\x66\x61ult_service\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12p\n\x14\x64\x65\x66\x61ult_url_redirect\x18\x04 \x01(\x0b\x32R.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXDefaultUrlRedirect\x12[\n\tpath_rule\x18\x05 \x03(\x0b\x32H.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXPathRule\x12_\n\x0broute_rules\x18\x06 \x03(\x0b\x32J.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcherXRouteRules\"\\\n\x18\x43omputeRegionUrlMapXTest\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x0f\n\x07service\x18\x04 \x01(\t\"N\n\x1c\x43omputeRegionUrlMapXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb1\x05\n\x13\x43omputeRegionUrlMap\x12\x1a\n\x12\x63reation_timestamp\x18\x01 \x01(\t\x12\x17\n\x0f\x64\x65\x66\x61ult_service\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0e\n\x06map_id\x18\x06 \x01(\x01\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\x0e\n\x06region\x18\t \x01(\t\x12\x11\n\tself_link\x18\n \x01(\t\x12\x64\n\x14\x64\x65\x66\x61ult_url_redirect\x18\x0b \x01(\x0b\x32\x46.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXDefaultUrlRedirect\x12O\n\thost_rule\x18\x0c \x03(\x0b\x32<.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXHostRule\x12U\n\x0cpath_matcher\x18\r \x03(\x0b\x32?.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXPathMatcher\x12\x46\n\x04test\x18\x0e \x03(\x0b\x32\x38.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXTest\x12N\n\x08timeouts\x18\x0f \x01(\x0b\x32<.oak9.tython.gcp.compute_region.ComputeRegionUrlMapXTimeouts\x12\x37\n\rresource_info\x18\x10 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_region_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEREGIONDISK_LABELSENTRY._options = None
  _COMPUTEREGIONDISK_LABELSENTRY._serialized_options = b'8\001'
  _COMPUTEREGIONINSTANCEGROUPMANAGER_STATUSENTRY._options = None
  _COMPUTEREGIONINSTANCEGROUPMANAGER_STATUSENTRY._serialized_options = b'8\001'
  _COMPUTEREGIONPERINSTANCECONFIGXPRESERVEDSTATE_METADATAENTRY._options = None
  _COMPUTEREGIONPERINSTANCECONFIGXPRESERVEDSTATE_METADATAENTRY._serialized_options = b'8\001'
  _COMPUTEREGIONAUTOSCALERXAUTOSCALINGPOLICYXCPUUTILIZATION._serialized_start=85
  _COMPUTEREGIONAUTOSCALERXAUTOSCALINGPOLICYXCPUUTILIZATION._serialized_end=186
  _COMPUTEREGIONAUTOSCALERXAUTOSCALINGPOLICYXLOADBALANCINGUTILIZATION._serialized_start=188
  _COMPUTEREGIONAUTOSCALERXAUTOSCALINGPOLICYXLOADBALANCINGUTILIZATION._serialized_end=272
  _COMPUTEREGIONAUTOSCALERXAUTOSCALINGPOLICYXMETRIC._serialized_start=274
  _COMPUTEREGIONAUTOSCALERXAUTOSCALINGPOLICYXMETRIC._serialized_end=368
  _COMPUTEREGIONAUTOSCALERXAUTOSCALINGPOLICYXSCALEINCONTROLXMAXSCALEDINREPLICAS._serialized_start=370
  _COMPUTEREGIONAUTOSCALERXAUTOSCALINGPOLICYXSCALEINCONTROLXMAXSCALEDINREPLICAS._serialized_end=480
  _COMPUTEREGIONAUTOSCALERXAUTOSCALINGPOLICYXSCALEINCONTROL._serialized_start=483
  _COMPUTEREGIONAUTOSCALERXAUTOSCALINGPOLICYXSCALEINCONTROL._serialized_end=709
  _COMPUTEREGIONAUTOSCALERXAUTOSCALINGPOLICYXSCALINGSCHEDULES._serialized_start=712
  _COMPUTEREGIONAUTOSCALERXAUTOSCALINGPOLICYXSCALINGSCHEDULES._serialized_end=915
  _COMPUTEREGIONAUTOSCALERXAUTOSCALINGPOLICY._serialized_start=918
  _COMPUTEREGIONAUTOSCALERXAUTOSCALINGPOLICY._serialized_end=1629
  _COMPUTEREGIONAUTOSCALERXTIMEOUTS._serialized_start=1631
  _COMPUTEREGIONAUTOSCALERXTIMEOUTS._serialized_end=1713
  _COMPUTEREGIONAUTOSCALER._serialized_start=1716
  _COMPUTEREGIONAUTOSCALER._serialized_end=2128
  _COMPUTEREGIONBACKENDSERVICEXBACKEND._serialized_start=2131
  _COMPUTEREGIONBACKENDSERVICEXBACKEND._serialized_end=2477
  _COMPUTEREGIONBACKENDSERVICEXCDNPOLICYXCACHEKEYPOLICY._serialized_start=2480
  _COMPUTEREGIONBACKENDSERVICEXCDNPOLICYXCACHEKEYPOLICY._serialized_end=2707
  _COMPUTEREGIONBACKENDSERVICEXCDNPOLICYXNEGATIVECACHINGPOLICY._serialized_start=2709
  _COMPUTEREGIONBACKENDSERVICEXCDNPOLICYXNEGATIVECACHINGPOLICY._serialized_end=2784
  _COMPUTEREGIONBACKENDSERVICEXCDNPOLICY._serialized_start=2787
  _COMPUTEREGIONBACKENDSERVICEXCDNPOLICY._serialized_end=3233
  _COMPUTEREGIONBACKENDSERVICEXCIRCUITBREAKERS._serialized_start=3236
  _COMPUTEREGIONBACKENDSERVICEXCIRCUITBREAKERS._serialized_end=3416
  _COMPUTEREGIONBACKENDSERVICEXCONSISTENTHASHXHTTPCOOKIEXTTL._serialized_start=3418
  _COMPUTEREGIONBACKENDSERVICEXCONSISTENTHASHXHTTPCOOKIEXTTL._serialized_end=3509
  _COMPUTEREGIONBACKENDSERVICEXCONSISTENTHASHXHTTPCOOKIE._serialized_start=3512
  _COMPUTEREGIONBACKENDSERVICEXCONSISTENTHASHXHTTPCOOKIE._serialized_end=3699
  _COMPUTEREGIONBACKENDSERVICEXCONSISTENTHASH._serialized_start=3702
  _COMPUTEREGIONBACKENDSERVICEXCONSISTENTHASH._serialized_end=3907
  _COMPUTEREGIONBACKENDSERVICEXFAILOVERPOLICY._serialized_start=3910
  _COMPUTEREGIONBACKENDSERVICEXFAILOVERPOLICY._serialized_end=4059
  _COMPUTEREGIONBACKENDSERVICEXIAP._serialized_start=4061
  _COMPUTEREGIONBACKENDSERVICEXIAP._serialized_end=4187
  _COMPUTEREGIONBACKENDSERVICEXLOGCONFIG._serialized_start=4189
  _COMPUTEREGIONBACKENDSERVICEXLOGCONFIG._serialized_end=4265
  _COMPUTEREGIONBACKENDSERVICEXOUTLIERDETECTIONXBASEEJECTIONTIME._serialized_start=4267
  _COMPUTEREGIONBACKENDSERVICEXOUTLIERDETECTIONXBASEEJECTIONTIME._serialized_end=4362
  _COMPUTEREGIONBACKENDSERVICEXOUTLIERDETECTIONXINTERVAL._serialized_start=4364
  _COMPUTEREGIONBACKENDSERVICEXOUTLIERDETECTIONXINTERVAL._serialized_end=4451
  _COMPUTEREGIONBACKENDSERVICEXOUTLIERDETECTION._serialized_start=4454
  _COMPUTEREGIONBACKENDSERVICEXOUTLIERDETECTION._serialized_end=5048
  _COMPUTEREGIONBACKENDSERVICEXTIMEOUTS._serialized_start=5050
  _COMPUTEREGIONBACKENDSERVICEXTIMEOUTS._serialized_end=5136
  _COMPUTEREGIONBACKENDSERVICE._serialized_start=5139
  _COMPUTEREGIONBACKENDSERVICE._serialized_end=6494
  _COMPUTEREGIONDISKXDISKENCRYPTIONKEY._serialized_start=6496
  _COMPUTEREGIONDISKXDISKENCRYPTIONKEY._serialized_end=6588
  _COMPUTEREGIONDISKXSOURCESNAPSHOTENCRYPTIONKEY._serialized_start=6590
  _COMPUTEREGIONDISKXSOURCESNAPSHOTENCRYPTIONKEY._serialized_end=6670
  _COMPUTEREGIONDISKXTIMEOUTS._serialized_start=6672
  _COMPUTEREGIONDISKXTIMEOUTS._serialized_end=6748
  _COMPUTEREGIONDISK._serialized_start=6751
  _COMPUTEREGIONDISK._serialized_end=7611
  _COMPUTEREGIONDISK_LABELSENTRY._serialized_start=7566
  _COMPUTEREGIONDISK_LABELSENTRY._serialized_end=7611
  _COMPUTEREGIONDISKIAMBINDINGXCONDITION._serialized_start=7613
  _COMPUTEREGIONDISKIAMBINDINGXCONDITION._serialized_end=7708
  _COMPUTEREGIONDISKIAMBINDING._serialized_start=7711
  _COMPUTEREGIONDISKIAMBINDING._serialized_end=7991
  _COMPUTEREGIONDISKIAMMEMBERXCONDITION._serialized_start=7993
  _COMPUTEREGIONDISKIAMMEMBERXCONDITION._serialized_end=8087
  _COMPUTEREGIONDISKIAMMEMBER._serialized_start=8090
  _COMPUTEREGIONDISKIAMMEMBER._serialized_end=8367
  _COMPUTEREGIONDISKIAMPOLICY._serialized_start=8370
  _COMPUTEREGIONDISKIAMPOLICY._serialized_end=8549
  _COMPUTEREGIONDISKRESOURCEPOLICYATTACHMENTXTIMEOUTS._serialized_start=8551
  _COMPUTEREGIONDISKRESOURCEPOLICYATTACHMENTXTIMEOUTS._serialized_end=8635
  _COMPUTEREGIONDISKRESOURCEPOLICYATTACHMENT._serialized_start=8638
  _COMPUTEREGIONDISKRESOURCEPOLICYATTACHMENT._serialized_end=8913
  _COMPUTEREGIONHEALTHCHECKXGRPCHEALTHCHECK._serialized_start=8916
  _COMPUTEREGIONHEALTHCHECKXGRPCHEALTHCHECK._serialized_end=9046
  _COMPUTEREGIONHEALTHCHECKXHTTP2HEALTHCHECK._serialized_start=9049
  _COMPUTEREGIONHEALTHCHECKXHTTP2HEALTHCHECK._serialized_end=9229
  _COMPUTEREGIONHEALTHCHECKXHTTPHEALTHCHECK._serialized_start=9232
  _COMPUTEREGIONHEALTHCHECKXHTTPHEALTHCHECK._serialized_end=9411
  _COMPUTEREGIONHEALTHCHECKXHTTPSHEALTHCHECK._serialized_start=9414
  _COMPUTEREGIONHEALTHCHECKXHTTPSHEALTHCHECK._serialized_end=9594
  _COMPUTEREGIONHEALTHCHECKXLOGCONFIG._serialized_start=9596
  _COMPUTEREGIONHEALTHCHECKXLOGCONFIG._serialized_end=9648
  _COMPUTEREGIONHEALTHCHECKXSSLHEALTHCHECK._serialized_start=9651
  _COMPUTEREGIONHEALTHCHECKXSSLHEALTHCHECK._serialized_end=9810
  _COMPUTEREGIONHEALTHCHECKXTCPHEALTHCHECK._serialized_start=9813
  _COMPUTEREGIONHEALTHCHECKXTCPHEALTHCHECK._serialized_end=9972
  _COMPUTEREGIONHEALTHCHECKXTIMEOUTS._serialized_start=9974
  _COMPUTEREGIONHEALTHCHECKXTIMEOUTS._serialized_end=10057
  _COMPUTEREGIONHEALTHCHECK._serialized_start=10060
  _COMPUTEREGIONHEALTHCHECK._serialized_end=11168
  _COMPUTEREGIONINSTANCEGROUPMANAGERXAUTOHEALINGPOLICIES._serialized_start=11170
  _COMPUTEREGIONINSTANCEGROUPMANAGERXAUTOHEALINGPOLICIES._serialized_end=11274
  _COMPUTEREGIONINSTANCEGROUPMANAGERXNAMEDPORT._serialized_start=11276
  _COMPUTEREGIONINSTANCEGROUPMANAGERXNAMEDPORT._serialized_end=11349
  _COMPUTEREGIONINSTANCEGROUPMANAGERXSTATEFULDISK._serialized_start=11351
  _COMPUTEREGIONINSTANCEGROUPMANAGERXSTATEFULDISK._serialized_end=11441
  _COMPUTEREGIONINSTANCEGROUPMANAGERXTIMEOUTS._serialized_start=11443
  _COMPUTEREGIONINSTANCEGROUPMANAGERXTIMEOUTS._serialized_end=11535
  _COMPUTEREGIONINSTANCEGROUPMANAGERXUPDATEPOLICY._serialized_start=11538
  _COMPUTEREGIONINSTANCEGROUPMANAGERXUPDATEPOLICY._serialized_end=11846
  _COMPUTEREGIONINSTANCEGROUPMANAGERXVERSIONXTARGETSIZE._serialized_start=11848
  _COMPUTEREGIONINSTANCEGROUPMANAGERXVERSIONXTARGETSIZE._serialized_end=11934
  _COMPUTEREGIONINSTANCEGROUPMANAGERXVERSION._serialized_start=11937
  _COMPUTEREGIONINSTANCEGROUPMANAGERXVERSION._serialized_end=12128
  _COMPUTEREGIONINSTANCEGROUPMANAGER._serialized_start=12131
  _COMPUTEREGIONINSTANCEGROUPMANAGER._serialized_end=13327
  _COMPUTEREGIONINSTANCEGROUPMANAGER_STATUSENTRY._serialized_start=13282
  _COMPUTEREGIONINSTANCEGROUPMANAGER_STATUSENTRY._serialized_end=13327
  _COMPUTEREGIONNETWORKENDPOINTGROUPXAPPENGINE._serialized_start=13329
  _COMPUTEREGIONNETWORKENDPOINTGROUPXAPPENGINE._serialized_end=13426
  _COMPUTEREGIONNETWORKENDPOINTGROUPXCLOUDFUNCTION._serialized_start=13428
  _COMPUTEREGIONNETWORKENDPOINTGROUPXCLOUDFUNCTION._serialized_end=13513
  _COMPUTEREGIONNETWORKENDPOINTGROUPXCLOUDRUN._serialized_start=13515
  _COMPUTEREGIONNETWORKENDPOINTGROUPXCLOUDRUN._serialized_end=13607
  _COMPUTEREGIONNETWORKENDPOINTGROUPXTIMEOUTS._serialized_start=13609
  _COMPUTEREGIONNETWORKENDPOINTGROUPXTIMEOUTS._serialized_end=13685
  _COMPUTEREGIONNETWORKENDPOINTGROUP._serialized_start=13688
  _COMPUTEREGIONNETWORKENDPOINTGROUP._serialized_end=14366
  _COMPUTEREGIONPERINSTANCECONFIGXPRESERVEDSTATEXDISK._serialized_start=14368
  _COMPUTEREGIONPERINSTANCECONFIGXPRESERVEDSTATEXDISK._serialized_end=14492
  _COMPUTEREGIONPERINSTANCECONFIGXPRESERVEDSTATE._serialized_start=14495
  _COMPUTEREGIONPERINSTANCECONFIGXPRESERVEDSTATE._serialized_end=14800
  _COMPUTEREGIONPERINSTANCECONFIGXPRESERVEDSTATE_METADATAENTRY._serialized_start=14753
  _COMPUTEREGIONPERINSTANCECONFIGXPRESERVEDSTATE_METADATAENTRY._serialized_end=14800
  _COMPUTEREGIONPERINSTANCECONFIGXTIMEOUTS._serialized_start=14802
  _COMPUTEREGIONPERINSTANCECONFIGXTIMEOUTS._serialized_end=14891
  _COMPUTEREGIONPERINSTANCECONFIG._serialized_start=14894
  _COMPUTEREGIONPERINSTANCECONFIG._serialized_end=15382
  _COMPUTEREGIONSSLCERTIFICATEXTIMEOUTS._serialized_start=15384
  _COMPUTEREGIONSSLCERTIFICATEXTIMEOUTS._serialized_end=15454
  _COMPUTEREGIONSSLCERTIFICATE._serialized_start=15457
  _COMPUTEREGIONSSLCERTIFICATE._serialized_end=15845
  _COMPUTEREGIONTARGETHTTPPROXYXTIMEOUTS._serialized_start=15847
  _COMPUTEREGIONTARGETHTTPPROXYXTIMEOUTS._serialized_end=15934
  _COMPUTEREGIONTARGETHTTPPROXY._serialized_start=15937
  _COMPUTEREGIONTARGETHTTPPROXY._serialized_end=16275
  _COMPUTEREGIONTARGETHTTPSPROXYXTIMEOUTS._serialized_start=16277
  _COMPUTEREGIONTARGETHTTPSPROXYXTIMEOUTS._serialized_end=16365
  _COMPUTEREGIONTARGETHTTPSPROXY._serialized_start=16368
  _COMPUTEREGIONTARGETHTTPSPROXY._serialized_end=16734
  _COMPUTEREGIONURLMAPXDEFAULTURLREDIRECT._serialized_start=16737
  _COMPUTEREGIONURLMAPXDEFAULTURLREDIRECT._serialized_end=16925
  _COMPUTEREGIONURLMAPXHOSTRULE._serialized_start=16927
  _COMPUTEREGIONURLMAPXHOSTRULE._serialized_end=17015
  _COMPUTEREGIONURLMAPXPATHMATCHERXDEFAULTURLREDIRECT._serialized_start=17018
  _COMPUTEREGIONURLMAPXPATHMATCHERXDEFAULTURLREDIRECT._serialized_end=17218
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXCORSPOLICY._serialized_start=17221
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXCORSPOLICY._serialized_end=17471
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXFAULTINJECTIONPOLICYXABORT._serialized_start=17473
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXFAULTINJECTIONPOLICYXABORT._serialized_end=17595
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXFAULTINJECTIONPOLICYXDELAYXFIXEDDELAY._serialized_start=17597
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXFAULTINJECTIONPOLICYXDELAYXFIXEDDELAY._serialized_end=17721
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXFAULTINJECTIONPOLICYXDELAY._serialized_start=17724
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXFAULTINJECTIONPOLICYXDELAY._serialized_end=17971
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXFAULTINJECTIONPOLICY._serialized_start=17974
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXFAULTINJECTIONPOLICY._serialized_end=18305
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXREQUESTMIRRORPOLICY._serialized_start=18307
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXREQUESTMIRRORPOLICY._serialized_end=18406
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXRETRYPOLICYXPERTRYTIMEOUT._serialized_start=18408
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXRETRYPOLICYXPERTRYTIMEOUT._serialized_end=18520
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXRETRYPOLICY._serialized_start=18523
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXRETRYPOLICY._serialized_end=18774
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXTIMEOUT._serialized_start=18776
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXTIMEOUT._serialized_end=18870
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXURLREWRITE._serialized_start=18872
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXURLREWRITE._serialized_end=18988
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXREQUESTHEADERSTOADD._serialized_start=18991
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXREQUESTHEADERSTOADD._serialized_end=19162
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_start=19165
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_end=19337
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTION._serialized_start=19340
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTION._serialized_end=19858
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXWEIGHTEDBACKENDSERVICES._serialized_start=19861
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXWEIGHTEDBACKENDSERVICES._serialized_end=20127
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTION._serialized_start=20130
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXROUTEACTION._serialized_end=21075
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXURLREDIRECT._serialized_start=21078
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULEXURLREDIRECT._serialized_end=21280
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULE._serialized_start=21283
  _COMPUTEREGIONURLMAPXPATHMATCHERXPATHRULE._serialized_end=21573
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXHEADERACTIONXREQUESTHEADERSTOADD._serialized_start=21576
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXHEADERACTIONXREQUESTHEADERSTOADD._serialized_end=21713
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_start=21716
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_end=21854
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXHEADERACTION._serialized_start=21857
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXHEADERACTION._serialized_end=22271
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXHEADERMATCHESXRANGEMATCH._serialized_start=22273
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXHEADERMATCHESXRANGEMATCH._serialized_end=22393
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXHEADERMATCHES._serialized_start=22396
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXHEADERMATCHES._serialized_end=22751
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXMETADATAFILTERSXFILTERLABELS._serialized_start=22753
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXMETADATAFILTERSXFILTERLABELS._serialized_end=22866
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXMETADATAFILTERS._serialized_start=22869
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXMETADATAFILTERS._serialized_end=23111
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXQUERYPARAMETERMATCHES._serialized_start=23114
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXQUERYPARAMETERMATCHES._serialized_end=23270
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXMATCHRULES._serialized_start=23273
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXMATCHRULES._serialized_end=23814
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXCORSPOLICY._serialized_start=23817
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXCORSPOLICY._serialized_end=24069
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXFAULTINJECTIONPOLICYXABORT._serialized_start=24071
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXFAULTINJECTIONPOLICYXABORT._serialized_end=24195
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXFAULTINJECTIONPOLICYXDELAYXFIXEDDELAY._serialized_start=24197
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXFAULTINJECTIONPOLICYXDELAYXFIXEDDELAY._serialized_end=24323
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXFAULTINJECTIONPOLICYXDELAY._serialized_start=24326
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXFAULTINJECTIONPOLICYXDELAY._serialized_end=24577
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXFAULTINJECTIONPOLICY._serialized_start=24580
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXFAULTINJECTIONPOLICY._serialized_end=24919
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXREQUESTMIRRORPOLICY._serialized_start=24921
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXREQUESTMIRRORPOLICY._serialized_end=25022
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXRETRYPOLICYXPERTRYTIMEOUT._serialized_start=25024
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXRETRYPOLICYXPERTRYTIMEOUT._serialized_end=25138
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXRETRYPOLICY._serialized_start=25141
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXRETRYPOLICY._serialized_end=25396
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXTIMEOUT._serialized_start=25398
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXTIMEOUT._serialized_end=25494
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXURLREWRITE._serialized_start=25496
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXURLREWRITE._serialized_end=25614
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXREQUESTHEADERSTOADD._serialized_start=25617
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXREQUESTHEADERSTOADD._serialized_end=25790
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_start=25793
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_end=25967
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTION._serialized_start=25970
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTION._serialized_end=26494
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXWEIGHTEDBACKENDSERVICES._serialized_start=26497
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXWEIGHTEDBACKENDSERVICES._serialized_end=26767
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTION._serialized_start=26770
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXROUTEACTION._serialized_end=27731
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXURLREDIRECT._serialized_start=27734
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULESXURLREDIRECT._serialized_end=27938
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULES._serialized_start=27941
  _COMPUTEREGIONURLMAPXPATHMATCHERXROUTERULES._serialized_end=28460
  _COMPUTEREGIONURLMAPXPATHMATCHER._serialized_start=28463
  _COMPUTEREGIONURLMAPXPATHMATCHER._serialized_end=28860
  _COMPUTEREGIONURLMAPXTEST._serialized_start=28862
  _COMPUTEREGIONURLMAPXTEST._serialized_end=28954
  _COMPUTEREGIONURLMAPXTIMEOUTS._serialized_start=28956
  _COMPUTEREGIONURLMAPXTIMEOUTS._serialized_end=29034
  _COMPUTEREGIONURLMAP._serialized_start=29037
  _COMPUTEREGIONURLMAP._serialized_end=29726
# @@protoc_insertion_point(module_scope)
